@@ -720,7 +720,7 @@ contacts_added (OssoABookRoster  *roster,
 }
 
 static void
-reset_contact (ELHomeApplet *self)
+reset_contact (ELHomeApplet *self, gboolean resize)
 {
         ELHomeAppletPrivate *priv = self->priv;
 
@@ -742,7 +742,8 @@ reset_contact (ELHomeApplet *self)
                 priv->contact = NULL;
         }
 
-        resize_sender (priv);
+        if (resize)
+                resize_sender (priv);
 }
 
 static void
@@ -759,13 +760,13 @@ contacts_removed (OssoABookRoster *roster,
 
                 for (contact_id = ids; *contact_id; contact_id++) {
                         if (strcmp (*contact_id, priv->contact_id) == 0) {
-                                reset_contact (self);
+                                reset_contact (self, TRUE);
 
                                 gtk_widget_queue_draw (GTK_WIDGET (self));
                                 return;
                         }
                         if (strcmp (*contact_id, uid) == 0) {
-                                reset_contact (self);
+                                reset_contact (self, TRUE);
                                 resolve_contact (self);
                                 gtk_widget_queue_draw (GTK_WIDGET (self));
                                 return;
@@ -775,11 +776,11 @@ contacts_removed (OssoABookRoster *roster,
 }
 
 static void
-clean_contact (ELHomeApplet *self)
+clean_contact (ELHomeApplet *self, gboolean resize)
 {
         ELHomeAppletPrivate *priv = self->priv;
 
-        reset_contact (self);
+        reset_contact (self, resize);
 
         if (priv->aggregator) {
                 if (priv->aggregator_ready_closure){
@@ -852,7 +853,7 @@ dispose (GObject *self)
         }
 
         clean_state (EL_HOME_APPLET (self));
-        clean_contact (EL_HOME_APPLET (self));
+        clean_contact (EL_HOME_APPLET (self), FALSE);
 
         G_OBJECT_CLASS (el_home_applet_parent_class)->dispose (self);
 }
@@ -1222,7 +1223,7 @@ read_event (ELHomeApplet *self)
                 if (g_strcmp0 (priv->remote_id, remote_id) ||
                     new_account ||
                     !priv->contact) {
-                        clean_contact (self);
+                        clean_contact (self, TRUE);
                         start_aggregator (self);
                 }
                 else if (priv->contact) {
@@ -1287,7 +1288,7 @@ read_event (ELHomeApplet *self)
                                     dgettext ("rtcom-messaging-ui",
                                               "messaging_ap_conversations"));
 
-                clean_contact (self);
+                clean_contact (self, TRUE);
                 gtk_widget_hide (priv->icon);
         }
 
